@@ -5,7 +5,7 @@ from starlette.requests import Request
 from starlette.responses import Response
 from starlette.types import ASGIApp
 
-from anydi import Container
+from anydi._container import Container
 
 
 class RequestScopedMiddleware(BaseHTTPMiddleware):
@@ -18,6 +18,6 @@ class RequestScopedMiddleware(BaseHTTPMiddleware):
     async def dispatch(
         self, request: Request, call_next: RequestResponseEndpoint
     ) -> Response:
-        async with self.container.arequest_context() as ctx:
-            ctx.set(Request, instance=request)
+        async with self.container.arequest_context() as context:
+            context.set(Request, request)
             return await call_next(request)
